@@ -15,8 +15,7 @@ from messager.utils import RABBIT_MQ_CREDENTIAL_PROBLEM
 from messager.utils import RABBIT_MQ_CONNECTION_PROBLEM
 from messager.utils import INCORRECT_MESSAGE, MISSING_SITE_ID
 from messager.utils import MISSING_NON_DST_TIMEZONE, MISSING_VARIABLE_ID
-from messager.utils import MISSING_DST_TIMEZONE, MISSING_DATE
-from messager.utils import MISSING_MESSAGE
+from messager.utils import MISSING_DST_TIMEZONE, MISSING_DATE, MISSING_VALUE
 from time import tzname
 from datetime import datetime
 import json
@@ -37,8 +36,8 @@ def validate_message(message):
             error = INCORRECT_MESSAGE % MISSING_SITE_ID % message
         elif "variableID" not in validated_message:
             error = INCORRECT_MESSAGE % MISSING_VARIABLE_ID % message
-        elif "message" not in validated_message:
-            error = INCORRECT_MESSAGE % MISSING_MESSAGE % message
+        elif "value" not in validated_message:
+            error = INCORRECT_MESSAGE % MISSING_VALUE % message
         elif "date" not in validated_message:
             error = INCORRECT_MESSAGE % MISSING_DATE % message
         elif "dstTimezone" not in validated_message:
